@@ -25,9 +25,8 @@ sub import {
  skip_all 'perl 5.13.4 required to test thread safety'
                                              unless $force or "$]" >= 5.013_004;
 
- my $desc = 'required to test thread safety';
- load_or_skip('threads',         $force ? '0' : '1.67', [ ], $desc);
- load_or_skip('threads::shared', $force ? '0' : '1.14', [ ], $desc);
+ load_or_skip_all('threads',         $force ? '0' : '1.67', [ ]);
+ load_or_skip_all('threads::shared', $force ? '0' : '1.14', [ ]);
 
  my %exports = (
   spawn => \&spawn,
